import csv
import datetime
import os

# Get the current date
current_date = datetime.date.today()

# Format the date as DD_MM
date_string = current_date.strftime("%d_%m")

# Create the subfolder path
subfolder = "csv_files"
os.makedirs(subfolder, exist_ok=True)


def merge_csv_files(smaller_file, bigger_file, output_file):
    # Read the smaller file and store its data in a dictionary
    smaller_data = read_csv_file(smaller_file)

    # Read the bigger file and store its data in a dictionary
    bigger_data = read_csv_file(bigger_file)

    # Assign price and quantity values from the bigger file to the smaller file
    for sku, smaller_row in smaller_data.items():
        if sku in bigger_data:
            bigger_row = bigger_data[sku]
            if 'price' in bigger_row and bigger_row['price'] != '0':
                smaller_row['price'] = bigger_row['price']
            else:
                smaller_row ['price'] = smaller_row['price']
                smaller_row['qty'] = '0'
            if 'qty' in bigger_row:
                smaller_row['qty'] = bigger_row['qty']
            else:
                smaller_row['qty'] = '0'
        else:
            smaller_row['qty'] = '0'
        
        # Remove "tim_" from SKU if present
        #smaller_row['sku'] = smaller_row['sku'].replace("tim_", "")

    # Write the updated data to the output file
    write_csv_file(smaller_data, output_file)


def read_csv_file(file_path):
    data = {}
    with open(file_path, 'r') as file:
        reader = csv.DictReader(file)
        for row in reader:
            sku = row['sku']
            data[sku] = {'price': row['price'], 'qty': row['qty']}
    return data


def write_csv_file(data, file_path):
    fieldnames = ['sku', 'price', 'qty']
    with open(file_path, 'w', newline='', encoding='utf-8-sig') as file:
        writer = csv.DictWriter(file, fieldnames=fieldnames)
        writer.writeheader()
        for sku, row in data.items():
            writer.writerow({'sku': sku, 'price': row['price'], 'qty': row['qty']})


# Usage example
smaller_file = 'csv_files/velo_listed.csv'
bigger_file = 'csv_files/merged.csv'
output_file = os.path.join(subfolder, f"final_csv_{date_string}.csv")

merge_csv_files(smaller_file, bigger_file, output_file)
